importScripts('https://storage.googleapis.com/workbox-cdn/releases/7.0.0/workbox-sw.js');

if (workbox) {
  console.log('Workbox is loaded. Preparing service worker.');

  // Precache the app shell (essential files)
  workbox.precaching.precacheAndRoute([
    { url: '/', revision: '1' },
    { url: '/index.html', revision: '1' },
    { url: '/style.css', revision: '1' },
    { url: '/script.js', revision: '1' },
    { url: '/manifest.json', revision: '1' },
    { url: '/offline.html', revision: '1' },
    // List all your static icons and images here
    { url: '/icons/clock.png', revision: '1' },
    { url: '/icons/reminder.png', revision: '1' },
    { url: '/icons/family.png', revision: '1' },
    { url: '/icons/call.png', revision: '1' },
    { url: '/icons/money.png', revision: '1' },
    { url: '/icons/meet.png', revision: '1' },
    { url: '/icons/notes.png', revision: '1' },
    { url: '/icons/help.png', revision: '1' },
    { url: '/icons/icon-72x72.png', revision: '1' },
    { url: '/icons/icon-96x96.png', revision: '1' },
    { url: '/icons/icon-128x128.png', revision: '1' },
    { url: '/icons/icon-144x144.png', revision: '1' },
    { url: '/icons/icon-152x152.png', revision: '1' },
    { url: '/icons/icon-192x192.png', revision: '1' },
    { url: '/icons/icon-384x384.png', revision: '1' },
    { url: '/icons/icon-512x512.png', revision: '1' },
    { url: '/icons/maskable_icon.png', revision: '1' }
  ]);

  // Cache Google Fonts (CSS and font files)
  workbox.routing.registerRoute(
    new RegExp('https://fonts.googleapis.com/.*'),
    new workbox.strategies.CacheFirst({
      cacheName: 'google-fonts-cache',
      plugins: [
        new workbox.expiration.ExpirationPlugin({
          maxEntries: 10,
          maxAgeSeconds: 60 * 60 * 24 * 365, // 1 year
        }),
      ],
    })
  );
  workbox.routing.registerRoute(
    new RegExp('https://fonts.gstatic.com/.*'),
    new workbox.strategies.CacheFirst({
      cacheName: 'google-fonts-webfonts-cache',
      plugins: [
        new workbox.expiration.ExpirationPlugin({
          maxEntries: 10,
          maxAgeSeconds: 60 * 60 * 24 * 365, // 1 year
        }),
      ],
    })
  );

  // Cache images (family images from Supabase Storage, etc.)
  workbox.routing.registerRoute(
    /\.(?:png|gif|jpg|jpeg|svg)$/,
    new workbox.strategies.CacheFirst({
      cacheName: 'image-cache',
      plugins: [
        new workbox.expiration.ExpirationPlugin({
          maxEntries: 50,
          maxAgeSeconds: 30 * 24 * 60 * 60, // 30 Days
        }),
      ],
    })
  );
  // Cache custom sound files (MP3)
  workbox.routing.registerRoute(
    /\.(?:mp3|wav|ogg)$/, // Add other audio formats if needed
    new workbox.strategies.CacheFirst({
      cacheName: 'audio-cache',
      plugins: [
        new workbox.expiration.ExpirationPlugin({
          maxEntries: 20, // Cache up to 20 audio files
          maxAgeSeconds: 30 * 24 * 60 * 60, // 30 Days
        }),
      ],
    })
  );

  // Cache dynamic data (like settings, reminders from Supabase)
  // IMPORTANT: Replace 'https://your-project.supabase.co' with your actual Supabase project URL
  workbox.routing.registerRoute(
    new RegExp(https://'rsmrozgkeieopetprsid.supabase.co/rest/v1/.*'), // Matches Supabase REST API calls
    new workbox.strategies.NetworkFirst({ // NetworkFirst tries network, then falls back to cache
      cacheName: 'supabase-data-cache',
      plugins: [
        new workbox.expiration.ExpirationPlugin({
          maxEntries: 100,
          maxAgeSeconds: 60 * 60 * 24, // 1 Day
        }),
        new workbox.cacheableResponse.CacheableResponsePlugin({
          statuses: [0, 200], // Cache opaque responses and successful ones
        })
      ],
    })
  );

  // Offline fallback for navigation requests
  workbox.routing.setDefaultHandler(new workbox.strategies.NetworkOnly());
  workbox.routing.setCatchHandler(async ({ event }) => {
    if (event.request.mode === 'navigate') {
      return caches.match('/offline.html');
    }
    return Response.error();
  });
} else {
  console.log('Workbox did not load');
}
